@@ -3,7 +3,7 @@ package Git::Code::Review;
 use strict;
 use warnings;
 
-our $VERSION = '2.2'; # VERSION
+our $VERSION = '2.3'; # VERSION
 
 use App::Cmd::Setup -app;
 
@@ -21,7 +21,7 @@ Git::Code::Review - Tools for performing code review using Git as the backend
 
 =head1 VERSION
 
-version 2.2
+version 2.3
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ This is free software, licensed under:
 
 =head1 CONTRIBUTORS
 
-=for stopwords Daniel Ostermeier Dennis Kaarsemaker Rafael Garcia-Suarez Samit Badle Sawyer X
+=for stopwords Daniel Ostermeier Dennis Kaarsemaker Rafael Garcia-Suarez Samit Badle Sawyer X Tigin Kaptanoglu
 
 =over 4
 
@@ -101,6 +101,10 @@ Samit Badle <Samit.Badle@gmail.com>
 
 Sawyer X <xsawyerx@cpan.org>
 
+=item *
+
+Tigin Kaptanoglu <tigin.kaptanoglu@booking.com>
+
 =back
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
